import { Chain, Network } from "@wormhole-foundation/sdk-base";
import { ChainToPlatform } from "@wormhole-foundation/sdk-base/src";
import { ChainContext, Signer, TokenBridge, TransactionId, TxHash, WormholeMessageId } from "@wormhole-foundation/sdk-definitions";
import { TokenTransferDetails } from "../types";
import { Wormhole } from "../wormhole";
import { AttestationId, TransferState, WormholeTransfer } from "../wormholeTransfer";
export declare class TokenTransfer<N extends Network> implements WormholeTransfer {
    private readonly wh;
    private state;
    transfer: TokenTransferDetails;
    txids: TransactionId[];
    vaas?: {
        id: WormholeMessageId;
        vaa?: TokenBridge.VAA<"Transfer" | "TransferWithPayload">;
    }[];
    private constructor();
    getTransferState(): Promise<TransferState>;
    static from<N extends Network>(wh: Wormhole<N>, from: TokenTransferDetails): Promise<TokenTransfer<N>>;
    static from<N extends Network>(wh: Wormhole<N>, from: WormholeMessageId, timeout?: number): Promise<TokenTransfer<N>>;
    static from<N extends Network>(wh: Wormhole<N>, from: TransactionId, timeout?: number): Promise<TokenTransfer<N>>;
    private static fromIdentifier;
    private static fromTransaction;
    initiateTransfer(signer: Signer): Promise<TxHash[]>;
    fetchAttestation(timeout?: number): Promise<AttestationId[]>;
    completeTransfer(signer: Signer): Promise<TxHash[]>;
    static transfer<N extends Network, C extends Chain, P extends ChainToPlatform<C>>(fromChain: ChainContext<N, P, C>, transfer: TokenTransferDetails, signer: Signer<N, C>): Promise<TransactionId[]>;
    static redeem<N extends Network, C extends Chain, P extends ChainToPlatform<C>>(toChain: ChainContext<N, P, C>, vaa: TokenBridge.VAA<"Transfer" | "TransferWithPayload">, signer: Signer<N, C>, automatic?: boolean): Promise<TransactionId[]>;
    static getTransferMessage<N extends Network>(wh: Wormhole<N>, tx: TransactionId, timeout?: number): Promise<WormholeMessageId>;
    static getTransferVaa<N extends Network>(wh: Wormhole<N>, whm: WormholeMessageId, timeout?: number): Promise<TokenBridge.VAA<"Transfer" | "TransferWithPayload">>;
    static validateTransferDetails<N extends Network>(wh: Wormhole<N>, transfer: TokenTransferDetails): Promise<void>;
}
//# sourceMappingURL=tokenTransfer.d.ts.map