import { PayloadDiscriminator, PayloadLiteral, WormholeMessageId, deserialize } from "@wormhole-foundation/sdk-definitions";
/**
 * Gets the bytes of a VAA for a given WormholeMessageId or `null` if the VAA is not available yet.
 * @param apiUrl the url of the wormholescan API
 * @param whm the WormholeMessageId
 * @returns a Uint8Array containing the VAA or `null` if it's not available yet
 * @throws Errors if the service throws an unrecoverable error (e.g. 500)
 */
export declare function getVaaBytes(apiUrl: string, whm: WormholeMessageId): Promise<Uint8Array | null>;
export declare function getVaaBytesWithRetry(apiUrl: string, whm: WormholeMessageId, timeout?: number): Promise<Uint8Array | undefined>;
export declare function getVaaWithRetry<T extends PayloadLiteral | PayloadDiscriminator>(apiUrl: string, whm: WormholeMessageId, decodeAs: T, timeout?: number): Promise<ReturnType<typeof deserialize<T>> | undefined>;
export interface TransactionStatus {
    id: string;
    timestamp: string;
    txHash: string;
    emitterChain: number;
    emitterAddress: string;
    emitterNativeAddress: string;
    payload: {
        amount: string;
        callerAppId: string;
        fee: string;
        fromAddress: string;
        parsedPayload: any;
        payload: string;
        payloadType: number;
        toAddress: string;
        toChain: number;
        tokenAddress: string;
        tokenChain: number;
    };
    standardizedProperties: {
        amount: string;
        appIds: string[];
        fee: string;
        feeAddress: string;
        feeChain: number;
        fromAddress: string;
        fromChain: number;
        toAddress: string;
        toChain: number;
        tokenAddress: string;
        tokenChain: number;
    };
    globalTx: {
        id: string;
        originTx: {
            txHash: string;
            from: string;
            status: string;
        };
        destinationTx?: {
            chainId: number;
            status: string;
            method: string;
            txHash: string;
            from: string;
            to: string;
            blockNumber: string;
            timestamp: string;
            updatedAt: string;
        };
    };
}
/**
 * Gets the status for a transaction given WormholeMessageId or `null` if the VAA is not available yet.
 * @param rpcUrl the url of the wormholescan API
 * @param whm the WormholeMessageId
 * @returns a TransactionStatus or `null` if it's not available yet
 * @throws Errors if the service throws an unrecoverable error (e.g. 500)
 */
export declare function getTransactionStatus(rpcUrl: string, whm: WormholeMessageId): Promise<TransactionStatus | null>;
export interface RelayData {
    from: {
        chain: string;
        chainId: number;
        txHash: string;
        senderAddress: string;
        symbol: string;
        amountSent: number;
        amountToSwap: number;
        estimatedNativeAssetAmount: number;
    };
    vaa: string;
    status: string;
    fee: {
        amount: number;
        symbol: string;
    };
    error: any;
    to: {
        chain: string;
        chainId: number;
        recipientAddress: string;
        txHash: string;
        gasUsed: number;
        nativeAssetSymbol: string;
        nativeAssetReceived: number;
    };
    metrics: {
        receivedAt: string;
        completedAt: string;
        failedAt: any;
        attempts: number;
        maxAttempts: number;
        waitingForTxInMs: number;
        waitingForWalletInMs: number;
    };
}
export declare function getRelayStatus(rpcUrl: string, txid: string): Promise<RelayData | null>;
//# sourceMappingURL=whscan-api.d.ts.map